Coverage for /Users/davegaeddert/Development/dropseed/plain/plain-sessions/plain/sessions/default_settings.py: 100%

1# Cookie name. This can be whatever you want.

2 SESSION_COOKIE_NAME = "sessionid"

3# Age of cookie, in seconds (default: 2 weeks).

4 SESSION_COOKIE_AGE = 60 * 60 * 24 * 7 * 2

5# A string like "example.com", or None for standard domain cookie.

6 SESSION_COOKIE_DOMAIN = None

7# Whether the session cookie should be secure (https:// only).

8 SESSION_COOKIE_SECURE = True

9# The path of the session cookie.

10 SESSION_COOKIE_PATH = "/"

11# Whether to use the HttpOnly flag.

12 SESSION_COOKIE_HTTPONLY = True

13# Whether to set the flag restricting cookie leaks on cross-site requests.

14# This can be 'Lax', 'Strict', 'None', or False to disable the flag.

15 SESSION_COOKIE_SAMESITE = "Lax"

16# Whether to save the session data on every request.

17 SESSION_SAVE_EVERY_REQUEST = False

18# Whether a user's session cookie expires when the web browser is closed.

19 SESSION_EXPIRE_AT_BROWSER_CLOSE = False

20# The module to store session data

21 SESSION_ENGINE = "plain.sessions.backends.db"